@@ -1,11 +1,7 @@
-// File Description
-/// \file BamRecordTag.h
-/// \brief Defines the BamRecordTag enum.
-//
-// Author: Derek Barnett
+#ifndef PBBAM_BAMRECORDTAG_H
+#define PBBAM_BAMRECORDTAG_H
 
-#ifndef BAMRECORDTAG_H
-#define BAMRECORDTAG_H
+#include <pbbam/Config.h>
 
 namespace PacBio {
 namespace BAM {
@@ -17,9 +13,15 @@ enum class BamRecordTag
     BARCODE_QUALITY,
     BARCODES,
     CONTEXT_FLAGS,
+    SEGMENT_ADAPTER_LEFT,
+    SEGMENT_ADAPTER_RIGHT,
+    SEGMENT_INDEX,
+    SEGMENT_SUPPLEMENTAL,
     DELETION_QV,
     DELETION_TAG,
     HOLE_NUMBER,
+    FORWARD_IPD,
+    FORWARD_PW,
     INSERTION_QV,
     IPD,
     LABEL_QV,
@@ -37,15 +39,21 @@ enum class BamRecordTag
     PULSE_MERGE_QV,
     PULSE_WIDTH,
     QUERY_END,
+    QUERY_END_FRAME_NUMBER,
     QUERY_START,
+    QUERY_START_FRAME_NUMBER,
     READ_ACCURACY,
     READ_GROUP,
+    REVERSE_IPD,
+    REVERSE_PW,
     SCRAP_REGION_TYPE,
     SCRAP_ZMW_TYPE,
-    SNR,
+    SIGNAL_TO_NOISE,
     START_FRAME,
     SUBSTITUTION_QV,
     SUBSTITUTION_TAG,
+    BASEMOD_LOCI,
+    BASEMOD_QV,
 
     //
     // not tags per se, but faking these here to simplify data fetching
@@ -57,4 +65,4 @@ enum class BamRecordTag
 }  // namespace BAM
 }  // namespace PacBio
 
-#endif  // BAMRECORDTAG_H
+#endif  // PBBAM_BAMRECORDTAG_H
